@@ -3,7 +3,7 @@ package Bit::Manip;
 use warnings;
 use strict;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 require XSLoader;
 XSLoader::load('Bit::Manip', $VERSION);
@@ -11,11 +11,12 @@ XSLoader::load('Bit::Manip', $VERSION);
 use Exporter qw(import);
 
 our @EXPORT_OK = qw(
+    bit_get
+    bit_set
+    bit_clr
     bit_bin
-    bit_count 
+    bit_count
     bit_mask
-    bit_get 
-    bit_set 
     bit_toggle
     bit_on
     bit_off
@@ -40,8 +41,8 @@ sub bit_count {
     return _bit_count($n, $set);
 }
 sub bit_mask {
-    my ($bits, $lsb) = @_;
-    return _bit_mask($bits, $lsb);
+    my ($nbits, $lsb) = @_;
+    return _bit_mask($nbits, $lsb);
 }
 sub bit_get {
     my ($data, $msb, $lsb) = @_;
@@ -50,9 +51,13 @@ sub bit_get {
 
     _bit_get($data, $msb, $lsb);
 }
+sub bit_clr {
+    my ($data, $lsb, $nbits) = @_;
+    return _bit_set($data, $lsb, $nbits, 0);
+}
 sub bit_set {
-    my ($data, $lsb, $bits, $value) = @_;
-    return _bit_set($data, $lsb, $bits, $value);
+    my ($data, $lsb, $nbits, $value) = @_;
+    return _bit_set($data, $lsb, $nbits, $value);
 }
 sub bit_toggle {
     my ($data, $bit) = @_;
@@ -60,11 +65,11 @@ sub bit_toggle {
 }
 sub bit_on {
     my ($data, $bit) = @_;
-    return _bit_toggle($data, $bit);
+    return _bit_on($data, $bit);
 }
 sub bit_off {
     my ($data, $bit) = @_;
-    return _bit_toggle($data, $bit);
+    return _bit_off($data, $bit);
 }
 sub _vim{};
 
@@ -103,15 +108,25 @@ Bit::Manip - Functions to simplify bit string manipulation
 
     $b = bit_set($b, 2, $num_bits, 0b101); # 10010100
 
-    my ($num_bits, $lsb) = (3, 2);
+    # clear some bits
 
+    $b = 0b11111111;
+
+    $num_bits = 3;
+    $lsb = 3;
+
+    $b = bit_clr($b, $lsb, $num_bits); # 11000111
+
+    # helpers
+
+    my ($num_bits, $lsb) = (3, 2);
     print bit_mask($num_bits, $lsb); # 28, or 11100
 
     print bit_bin(255); # 11111111 (same as printf("%b", 255);)
       
 =head1 DESCRIPTION
 
-Provides functions to aid in bit manipulation (set, unset, toggle, shifting)
+Provides functions to aid in bit manipulation (get, set, clear, toggle)
 etc. Particularly useful for embedded programming and writing device
 communication software.
 
@@ -122,50 +137,18 @@ Currently, up to 32-bit integers are supported.
 Use the C<:all> tag (eg: C<use Bit::Manip qw(:all);>) to import the following
 functions into your namespace, or pick and choose individually:
 
-    bit_bin
-    bit_count 
-    bit_mask
-    bit_get 
-    bit_set 
+    bit_get
+    bit_set
+    bit_clr
     bit_toggle
     bit_on
     bit_off
+    bit_bin
+    bit_count
+    bit_mask
 
 =head1 FUNCTIONS
 
-=head2 bit_bin
-
-Returns the binary representation of a number as a string of ones and zeroes.
-
-Parameters:
-
-    $data
-
-Mandatory: Integer, the number you want to convert.
-
-=head2 bit_count
-
-Returns either the total count of bits in a number, or just the number of set
-bits (if the C<$set>, parameter is sent in and is true).
-
-Parameters:
-
-    $num
-
-Mandatory: Unsigned integer, the number to retrieve the total number of bits
-for. For example, if you send in C<15>, the total number of bits would be C<4>,
-likewise, for C<255>, the number of bits would be C<16>.
-
-    $set
-
-Optional: Integer. If this is sent and is a true value, we'll return the number
-of *set* bits only. For example, for C<255>, the set bits will be C<8> (ie. all
-of them), and for C<8>, the return will be C<1> (as only the MSB is set out of
-all four of the total).
-
-Return: Integer, the number of bits that make up the number if C<$set> is C<0>,
-and the number of set bits (1's) if C<$set> is true.
-
 =head2 bit_get
 
 Retrieves the value of specified bits within a bit string.
@@ -209,7 +192,7 @@ Mandatory: Integer, the least significant bit (rightmost) in the bit range you
 want to manipulate. For example, if you wanted to set a new value for bits
 C<7-5>, you'd send in C<5>.
 
-    $bits
+    $nbits
 
 Mandatory: Integer, the number of bits you're sending in. We need this param
 in the event your leading bit is a zero. For example, if you're sending in
@@ -241,6 +224,29 @@ Code:
     my $x = bit_set($data, 4, 3, 0b111); # (0x07, or 7)
     printf("%b\n", $x); # prints 11110000
 
+=head2 bit_clr
+
+Clear (unset to 0) specific bits in the bit string.
+
+Parameters:
+
+    $data
+
+Mandatory: Integer, the bit string you want to manipulate bits in.
+
+    $lsb
+
+Mandatory: Integer, the least significant bit (rightmost) in the bit range you
+want to manipulate. For example, if you wanted to clear bits C<7-5>, you'd send
+in C<5>.
+
+    $nbits
+
+Mandatory: Integer, the number of bits you're wanting to clear, starting from
+the C<$lsb> bit, and clearing the number of bits to the left.
+
+Returns the modified bit string.
+
 =head2 bit_toggle
 
 Toggles a single bit. If it's C<0> it'll toggle to C<1> and vice-versa.
@@ -260,7 +266,8 @@ Return: Integer, the modified C<$data> param.
 
 =head2 bit_on
 
-Sets a single bit (sets to C<1>), regardless of its current state.
+Sets a single bit (sets to C<1>), regardless of its current state. This is just
+a short form of setting a single bit with L<bit_set>.
 
 Parameters:
 
@@ -277,7 +284,8 @@ Return: Integer, the modified C<$data> param.
 
 =head2 bit_off
 
-Unsets a single bit (sets to C<0>), regardless of its current state.
+Unsets a single bit (sets to C<0>), regardless of its current state. This is
+just a short form of clearing a single bit with L<bit_set>.
 
 Parameters:
 
@@ -292,13 +300,46 @@ starting from C<0>.
 
 Return: Integer, the modified C<$data> param.
 
+=head2 bit_bin
+
+Returns the binary representation of a number as a string of ones and zeroes.
+
+Parameters:
+
+    $data
+
+Mandatory: Integer, the number you want to convert.
+
+=head2 bit_count
+
+Returns either the total count of bits in a number, or just the number of set
+bits (if the C<$set>, parameter is sent in and is true).
+
+Parameters:
+
+    $num
+
+Mandatory: Unsigned integer, the number to retrieve the total number of bits
+for. For example, if you send in C<15>, the total number of bits would be C<4>,
+likewise, for C<255>, the number of bits would be C<16>.
+
+    $set
+
+Optional: Integer. If this is sent and is a true value, we'll return the number
+of *set* bits only. For example, for C<255>, the set bits will be C<8> (ie. all
+of them), and for C<8>, the return will be C<1> (as only the MSB is set out of
+all four of the total).
+
+Return: Integer, the number of bits that make up the number if C<$set> is C<0>,
+and the number of set bits (1's) if C<$set> is true.
+
 =head2 bit_mask
 
 Generates a bit mask for the specific bits you specify.
 
 Parameters:
 
-    $bits
+    $nbits
 
 Mandatory: Integer, the number of bits to get the mask for.
 
